<?php
if (!defined('ABSPATH')) {
    exit;
}
/*
  Slipt according to exist attribute
 * */

if (!class_exists('wosc_default_class')) {

    class wosc_default_class {

        /**
         * @var string 
         */
        public $name = "WooCommerce Split Order";

        /**
         * @var string 
         */
        public $description = "Split orders";

        public function __construct() {
            $this->default_init();
        }

        public function default_init() {
            if (!is_admin() || (defined('DOING_AJAX') && DOING_AJAX)) {
                $this->default_frontend_variation();
            }
        }

        public function default_frontend_variation() {
            add_action('woocommerce_checkout_order_processed', array($this, 'wosc_change_total_on_checking'), 20, 1);
            remove_filter('woocommerce_thankyou_order_received_text', 'filter_woocommerce_thankyou_order_received_text', 10, 2);
            add_filter('woocommerce_thankyou_order_received_text', array($this, 'sunarc_change_order_received_text'), 10, 2);
            add_filter('woocommerce_locate_template', array($this, 'sunarc_thank_you_page_template'), 20, 3);
        }

        public function wosc_change_total_on_checking($order_id) {
		    
            $items = WC()->cart->get_cart();
            update_post_meta($order_id, 'ordered_items_for_split', $items);
            $packages = WC()->shipping()->get_packages();
            update_post_meta($order_id, 'ordered_shipping_for_split', $packages);
            
        }

        function sunarc_change_order_received_text($str, $order) {
            $order_id = method_exists($order, 'get_id') ? $order->get_id() : $order->id;
            $str .= $this->wosc_change_order_received_text($order_id);
            return $str;
        }

        function wosc_change_order_received_text($order_id, $deleted = true) {

            /* Send combine order email */
            if (get_post_meta($order_id, 'order_email_sent', true) !== 'yes') {
                $this_order = wc_get_order($order_id);
                $this_order->calculate_totals();
                $wc_mailer = WC()->mailer();
                $mails = $wc_mailer->get_emails();

                //Notification for New Order to Management.
                $new_order_email_template = $mails['WC_Email_New_Order'];
                $new_order_email_template->trigger($order_id);

                //Notification for Order Processed to Customer.
                $new_order_email_template = $mails['WC_Email_Customer_Processing_Order'];
                $new_order_email_template->trigger($order_id);

                update_post_meta($order_id, 'order_email_sent', 'yes');
            }

            $order          = wc_get_order($order_id);
            $paymentMethod  = $order->get_payment_method_title();
            $method         = $order->get_payment_method();
            //$order->update_status('processing');

            $items = get_post_meta($order_id, 'ordered_items_for_split');//WC()->cart->get_cart();

            $already_split = get_post_meta($order_id, 'order_ids', true);

            if (empty($already_split)) {
             
            $orderIds = array();
            $i = 1;
            foreach ($items[0] as $item => $values) {
                $address = array(
                    'first_name'    => sanitize_text_field($order->get_billing_first_name()),
                    'last_name'     => sanitize_text_field($order->get_billing_last_name()),
                    'company'       => sanitize_text_field($order->get_billing_company()),
                    'email'         => sanitize_email($order->get_billing_email()),
                    'phone'         => sanitize_text_field($order->get_billing_phone()),
                    'address_1'     => sanitize_text_field($order->get_billing_address_1()),
                    'address_2'     => sanitize_text_field($order->get_billing_address_2()),
                    'city'          => sanitize_text_field($order->get_billing_city()),
                    'state'         => sanitize_text_field($order->get_billing_state()),
                    'postcode'      => sanitize_text_field($order->get_billing_postcode()),
                    'country'       => sanitize_text_field($order->get_billing_country())
                    
                );
                $shippingaddress = array(
                    'first_name'    => sanitize_text_field($order->get_shipping_first_name()),
                    'last_name'     => sanitize_text_field($order->get_shipping_last_name()),
                    'company'       => sanitize_text_field($order->get_shipping_company()),
                    //'email'         => sanitize_email($_POST['shipping_email']),
                    //'phone'         => sanitize_text_field($_POST['shipping_phone']),
                    'address_1'     => sanitize_text_field($order->get_shipping_address_1()),
                    'address_2'     => sanitize_text_field($order->get_shipping_address_2()),
                    'city'          => sanitize_text_field($order->get_shipping_city()),
                    'state'         => sanitize_text_field($order->get_shipping_state()),
                    'postcode'      => sanitize_text_field($order->get_shipping_postcode()),
                    'country'       => sanitize_text_field($order->get_shipping_country())
            
                );
                
                $user_id = get_current_user_id();
                
                /* Update existing orders and create new orders */
                if ($i!==1) {
                    $order = wc_create_order();
                }
                
                $order->update_status('processing');
                $note = ($_POST['order_comments'])? sanitize_text_field($_POST['order_comments']) : '';
                $order->set_customer_note( $note );
                $order->set_address($address, 'billing');
                $order->set_address($shippingaddress, 'shipping');
                update_post_meta($order->get_id(), '_customer_user', $user_id);
                $my_post = array( 'ID' => $order->get_id(), 'post_excerpt' => $note, );
                             
                wp_update_post( $my_post );
                update_post_meta($order->get_id(), 'order_status_result','Split Order');
                update_post_meta($order->get_id(), '_order_ispliter', 'yes');
                update_post_meta($order->get_id(), '_payment_method_title', $paymentMethod);
                update_post_meta($order->get_id(), '_payment_method', $method);
                if ($i!==1) {
                    update_post_meta($order->get_id(), '_order_key', 'wc_' . apply_filters('woocommerce_generate_order_key', uniqid('order_')));
                }
                update_post_meta($order->get_id(), '_order_currency', get_woocommerce_currency());
                update_post_meta($order->get_id(), '_prices_include_tax', get_option('woocommerce_prices_include_tax'));
                update_post_meta($order->get_id(), '_customer_ip_address', isset($_SERVER['HTTP_X_FORWARDED_FOR']) ? $_SERVER['HTTP_X_FORWARDED_FOR'] : $_SERVER['REMOTE_ADDR']);
                update_post_meta($order->id, '_customer_user_agent', isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '');
                $sum            = $values['line_total'];
                $_product       = $values['data']->post;
                $product_title  = $_product->post_title;
                $qty            = $values['quantity'];
                $price          = get_post_meta($values['product_id'], '_price', true);
                $variation_id   = $values['variation_id'];

                // get order items = each product in the order
                $ordereditems = $order->get_items();
                foreach ( $ordereditems as $ordereditem ) {
                    $order->remove_item( $ordereditem->get_id() );
                }

                $order->calculate_totals();
                
                $item_id = wc_add_order_item($order->get_id(), array(
                                            'order_item_name' => $product_title,
                                            'order_item_type' => 'line_item'
                                        ));
                if ($item_id) {
                    // add item meta data
                    wc_add_order_item_meta($item_id, '_qty', $qty);
                    wc_add_order_item_meta($item_id, '_tax_class', $values['tax_class']);
                    wc_add_order_item_meta($item_id, '_product_id', $values['product_id']);
                    wc_add_order_item_meta($item_id, '_variation_id', $variation_id);
                    wc_add_order_item_meta($item_id, '_line_subtotal', $values['line_subtotal']);
                    wc_add_order_item_meta($item_id, '_line_subtotal_tax', $values['line_subtotal_tax']);
                    wc_add_order_item_meta($item_id, '_line_total', $values['line_total']);
                    wc_add_order_item_meta($item_id, '_line_tax', $values['line_tax']);
                    wc_add_order_item_meta($item_id, '_line_tax_data', array('total' => array($values['total']), 'subtotal' => array($values['subtotal'])));
                    if ($values['variation_data'] && is_array($item['variation_data'])) {
                        foreach ($item['variation_data'] as $key => $value) {
                            wc_add_order_item_meta($item_id, str_replace('attribute_', '', $key), $value);
                        }
                    }
                }

                

                update_post_meta($order->get_id(), '_order_total', wc_format_decimal($sum, get_option('woocommerce_price_num_decimals')));
                $orderIds[] = $order->get_id();
                $i++;
            }
            update_post_meta($order_id, 'order_ids', serialize($orderIds));
            


            }
		   
            $woocommerceCurrency = get_woocommerce_currency_symbol(get_option('woocommerce_currency'));

            ob_start();
            
            $posts_array = unserialize(get_post_meta($order_id, 'order_ids', true));

            if (!empty($posts_array)) { 
                if (get_post_meta($order_id, 'order_splitted_done', true)!=='yes') { 
                    
                    update_post_meta($order_id, 'order_splitted_done', 'yes');
                }
                
                ?>
                <section class="woocommerce-order-details child_orderss">
                    <h2 class="woocommerce-order-details-title"><?php echo 'Split Order' . (count($posts_array) > 1 ? 's' : ''); ?></h2>
                    <?php
                    foreach ($posts_array as $post_data) {
                        $child_order        = wc_get_order($post_data);
                        $paymentMethod      = $child_order->get_payment_method_title();
                        $shipping_amt       = $child_order->get_shipping_to_display();
                        $child_order_data   = $child_order->get_data();
                        ?>

                        <h3 class="child_order_heading"><?php echo 'Order number'; ?> <?php echo $post_data; ?></h3>
                        <table class="woocommerce-table woocommerce-table--order-details shop_table order_details">
                            <thead>
                                <tr>
                                    <th class="woocommerce-table-product-name product-name">Product</th>
                                    <th class="woocommerce-table-product-table product-total">Total</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($child_order->get_items() as $order_items) { ?>    
                                    <tr class="woocommerce-table-line-item order_item">
                                        <td class="woocommerce-table-product-name product-name">
                                            <a href="<?php echo get_permalink($order_items->get_product_id()); ?>"><?php echo $order_items['name']; ?></a> <strong class="product-quantity">&times; — <?php echo $order_items->get_quantity(); ?></strong></td>

                                        <td class="woocommerce-table-product-total product-total">
                                            <span class="woocommerce-Price-amount amount"><span class="woocommerce-Price-currencySymbol">
                                                    <?php //echo $woocommerceCurrency; ?>
                                                </span><?php echo $woocommerceCurrency.number_format($order_items->get_total(), 2); ?></span></td>
                                    </tr>
                                    <?php
                                    $purchase_note = get_post_meta( $order_items['product_id'], '_purchase_note', true);
                                    if(!empty($purchase_note)){
                                    ?>
                                    <tr class="woocommerce-table__product-purchase-note product-purchase-note">
                                        <td colspan="2"><p><?php echo $purchase_note; ?></p></td>
                                    </tr>
                                <?php } 
                                } ?>
                                <tr>
                                    <td>Tax:	</td>	
                                    <td><span class="woocommerce-Price-currencySymbol">
                                            <?php //echo $woocommerceCurrency; ?>
                                        </span>
                                        <?php echo $woocommerceCurrency.number_format($child_order_data['total_tax'], 2); ?>
                                    </td>	
                                </tr>
                                <tr>
                                    <td>Shipping: </td>   
                                    <td><?php echo $shipping_amt; ?></td>  
                                </tr>
                                <tr>
                                    <td>Payment method:	</td>	
                                    <td><?php echo $paymentMethod; ?></td>	
                                </tr>
                            </tbody>
                            <tfoot>
                                <tr>
                                    <th scope="row">Total:</th>
                                    <td>
                                        <span class="woocommerce-Price-amount amount"><span class="woocommerce-Price-currencySymbol">
                                                <?php echo $woocommerceCurrency; ?>
                                            </span>
                                            <?php echo number_format($child_order->get_total(), 2); ?>
                                        </span>
                                    </td>
                                </tr>
                            </tfoot>
                        </table>
                        <?php
                    }
                    ?>

                </section>
                <?php
            }
            $str = ob_get_contents();
            ob_end_clean();
            return $str;
        }


       
        public function sunarc_thank_you_page_template($template, $template_name, $template_path) {
            if ('checkout/thankyou.php' == $template_name) {
                $template = wosc_sunarc_plugin_dir . '/include/checkout/thankyou.php';
            }
            return $template;
			
        }
		
			
    }
	 	

}
new wosc_default_class();
?>